@@ -77,9 +77,9 @@ def intercept_errors(
                 if not (quiet or quiet_):
                     sys.stderr.write(message)
                 if suppress or suppress_:
-                    raise SuppressedError(shlex.join(err.cmd)) from err
+                    raise SuppressedError(err) from err
                 else:
-                    raise FailedSubprocessError(shlex.join(err.cmd)) from err
+                    raise FailedSubprocessError(err) from err
 
         return cast(F, wrapped)
 
@@ -132,7 +132,9 @@ def setup_segment(**kwargs: Any) -> Callable[[F], F]:
 
 
 def setup_sentry(**kwargs: Any) -> Callable[[F], F]:
-    sentry_init(**kwargs)
+    environment = "pypi" if ProdMode else "development"
+    sample_rate = 1.0 if ProdMode else 0.0
+    sentry_init(environment=environment, sample_rate=sample_rate, **kwargs)
 
     def decorator(fn: F) -> F:
         @click.pass_context
