@@ -15,6 +15,7 @@ from ..errors import (
     InstanceNotFound,
     raise_if_match,
 )
+from .config import SymConfigFile
 from .params import get_ssh_user
 
 InstanceIDPattern = re.compile("^i-[a-f0-9]+$")
@@ -48,7 +49,7 @@ def boto_client(saml_client, service):
 
 
 @intercept_boto_errors
-def send_ssh_key(saml_client: "SAMLClient", instance: str, ssh_key: "SymConfigFile"):
+def send_ssh_key(saml_client: "SAMLClient", instance: str, ssh_key: SymConfigFile):
     user = get_ssh_user()
     ssm_client = boto_client(saml_client, "ssm")
     # fmt: off
