@@ -17,11 +17,16 @@ def keywords_to_options(args: Sequence[Argument]) -> List[str]:
     for arg in args:
         if isinstance(arg, str):
             result.append(arg)
-        else:
-            for (key, value) in arg.items():
-                option = "--" + key.replace("_", "-")
-                if value:
-                    result.append(option)
-                    if isinstance(value, str):
-                        result.append(value)
+            continue
+        for (key, value) in arg.items():
+            if value is False:
+                continue
+            prefix = "-" if len(key) == 1 else "--"
+            option = prefix + key.replace("_", "-")
+            if not isinstance(value, list):
+                value = [value]
+            for val in value:
+                result.append(option)
+                if isinstance(val, str):
+                    result.append(val)
     return result
