@@ -1,11 +1,17 @@
 import re
 from datetime import datetime, timedelta
+from pathlib import Path
 from subprocess import CalledProcessError
 from textwrap import dedent
 from typing import Sequence
 
 from ..decorators import intercept_errors, run_subprocess
-from ..errors import AccessDenied, TargetNotConnected, WrappedSubprocessError
+from ..errors import (
+    AccessDenied,
+    SuppressedError,
+    TargetNotConnected,
+    WrappedSubprocessError,
+)
 from ..helpers.boto import send_ssh_key
 from ..helpers.config import Config, SymConfigFile
 from ..helpers.params import get_ssh_user
@@ -13,24 +19,30 @@ from ..helpers.params import get_ssh_user
 MissingPublicKeyPattern = re.compile(r"Permission denied \(.*publickey.*\)")
 TargetNotConnectedPattern = re.compile("TargetNotConnected")
 AccessDeniedPattern = re.compile("AccessDeniedException")
+ConnectionClosedPattern = re.compile(r"Connection to .* closed")
 
-SSHConfig = SymConfigFile("ssh/config")
-SSHKey = SymConfigFile("ssh/key")
+SSHConfigPath = "ssh/config"
+SSHKeyPath = "ssh/key"
 
 
 @intercept_errors()
 @run_subprocess
 def gen_ssh_key(dest: SymConfigFile):
-    dest.path.parent.mkdir(parents=True, exist_ok=True)
-    dest.path.unlink(missing_ok=True)
-    yield "ssh-keygen", {"t": "rsa", "f": str(dest), "N": ""}
+    with dest.exclusive_create() as f:
+        Path(f.name).unlink(missing_ok=True)
+        yield "ssh-keygen", {"t": "rsa", "f": f.name, "N": ""}
 
 
 def ssh_args(client, instance, port) -> tuple:
     return (
         "ssh",
         instance,
-        {"p": str(port), "F": str(SSHConfig), "l": get_ssh_user(), "v": client.debug},
+        {
+            "p": str(port),
+            "F": str(client.subconfig(SSHConfigPath)),
+            "l": get_ssh_user(),
+            "v": client.debug,
+        },
     )
 
 
@@ -68,6 +80,8 @@ def start_ssh_session(
             raise TargetNotConnected() from err
         elif AccessDeniedPattern.search(err.stderr):
             raise AccessDenied() from err
+        elif ConnectionClosedPattern.search(err.stderr):
+            raise SuppressedError(err, echo=True) from err
         else:
             raise WrappedSubprocessError(
                 err, f"Contact your Sym administrator.", report=True
@@ -78,14 +92,14 @@ def start_ssh_session(
 
 @intercept_errors({TargetNotConnectedPattern: TargetNotConnected}, suppress=True)
 def ensure_ssh_key(client, instance: str, port: int):
-    # Write the SSH Config first, we need to do this regardles of whether the
-    # SSH Key is present on the box.
+    ssh_key = client.subconfig(SSHKeyPath)
+    ssh_config = client.subconfig(SSHConfigPath)
 
     # fmt: off
-    SSHConfig.put(dedent(
+    ssh_config.put(dedent(  # Ensure the SSH Config first, always
         f"""
-        Host {instance}
-            IdentityFile {str(SSHKey)}
+        Host *
+            IdentityFile {str(ssh_key)}
             PreferredAuthentications publickey
             PubkeyAuthentication yes
             StrictHostKeyChecking no
@@ -99,13 +113,13 @@ def ensure_ssh_key(client, instance: str, port: int):
 
     instance_config = Config.get_instance(instance)
 
-    if SSHKey.path.exists():
-        last_connect = instance_config.get("last_connection")
-        if last_connect and datetime.now() - last_connect < timedelta(days=1):
-            client.dprint(f"Skipping remote SSH key check for {instance}")
-            return
-    else:
-        gen_ssh_key(SSHKey, capture_output_=True)
+    if not ssh_key.path.exists():
+        gen_ssh_key(ssh_key, capture_output_=True)
+
+    last_connect = instance_config.get("last_connection")
+    if last_connect and datetime.now() - last_connect < timedelta(days=1):
+        client.dprint(f"Skipping remote SSH key check for {instance}")
+        return
 
     try:
         _start_background_ssh_session(
@@ -114,7 +128,7 @@ def ensure_ssh_key(client, instance: str, port: int):
     except CalledProcessError as err:
         if not MissingPublicKeyPattern.search(err.stderr):
             raise
-        send_ssh_key(client, instance, SSHKey)
+        send_ssh_key(client, instance, ssh_key)
     else:
         return
 
