@@ -1,5 +1,5 @@
 import shlex
-from configparser import ConfigParser
+from configparser import ConfigParser, NoOptionError, NoSectionError
 from pathlib import Path
 from typing import Final, Iterator, Optional, Tuple
 
@@ -28,6 +28,17 @@ class Saml2Aws(SAMLClient):
         super().__init__(resource, debug=debug)
         self.config_file = SymConfigFile(resource=resource, file_name="saml2aws.cfg")
 
+    def is_setup(self) -> bool:
+        path = Path.home() / ".saml2aws"
+        if not path.exists():
+            return False
+        config = ConfigParser()
+        config.read(path)
+        try:
+            return bool(config.get("default", "username"))
+        except (NoSectionError, NoOptionError):
+            return False
+
     @intercept_errors(ErrorPatterns)
     @run_subprocess
     @require_bins(binary)
@@ -37,6 +48,7 @@ class Saml2Aws(SAMLClient):
             "verbose": self.debug,
             "config": str(self.config_file),
             "idp_account": "sym",
+            "skip-prompt": True,
         }
         config = self.ensure_config()
         # saml2aws exec actually joins all the arguments into a single string and
