@@ -13,12 +13,18 @@ from click.testing import CliRunner
 from sym.cli.commands import GlobalOptions
 from sym.cli.helpers import boto
 from sym.cli.helpers.config import Config
+from sym.cli.saml_clients import SAMLClient
 from sym.cli.saml_clients.aws_okta import AwsOkta
 from sym.cli.sym import sym as click_command
 from sym.cli.tests.helpers.capture import CaptureCommand
 from sym.cli.tests.helpers.sandbox import Sandbox
 
 
+@pytest.fixture(autouse=True)
+def patch_is_setup(monkeypatch: MonkeyPatch):
+    monkeypatch.setattr(SAMLClient, "check_is_setup", lambda self: ...)
+
+
 @pytest.fixture
 def sandbox(tmp_path: Path) -> Sandbox:
     return Sandbox(tmp_path)
