@@ -7,18 +7,20 @@ from _pytest.monkeypatch import MonkeyPatch
 
 
 class CaptureCommand:
-    __slots__ = ["monkeypatch", "commands"]
+    __slots__ = ["monkeypatch", "commands", "outputs"]
 
     def __init__(self, monkeypatch: MonkeyPatch):
         self.monkeypatch = monkeypatch
         self.commands: List[List[str]] = []
+        self.outputs = []
 
     # This function is designed for capturing the run_subprocess decorator only.
     # It is not intended to capture subprocess.run calls generally. For example,
     # `args` has a much more constrained type than subprocess.run normally allows.
     def _run_stub(self, args: Sequence[str], **_kwargs: Any) -> None:
         self.commands.append(list(args))
-        return subprocess.CompletedProcess(args=args, returncode=0)
+        output = self.outputs.pop() if self.outputs else None
+        return subprocess.CompletedProcess(args=args, returncode=0, stdout=output)
 
     @contextmanager
     def __call__(self) -> Iterator[None]:
@@ -26,6 +28,9 @@ class CaptureCommand:
             mp.setattr(subprocess, "run", self._run_stub)
             yield
 
+    def enqueue_output(self, output: str) -> None:
+        self.outputs.append(output)
+
     def assert_command(self, *commands: str) -> None:
         assert len(self.commands) == len(commands)
         for (actual, expected) in zip(self.commands, commands):
