@@ -22,9 +22,7 @@ class Sandbox:
                 f.write(contents)
 
     @contextmanager
-    def create_file_with_content(
-        self, name: str, mode: int = 0o644
-    ) -> Iterator[TextIO]:
+    def create_file_with_content(self, name: str, mode: int = 0o644) -> Iterator[TextIO]:
         path = self.path / name
         path.parent.mkdir(parents=True, exist_ok=True)
         with path.open("x") as f:
