@@ -4,6 +4,7 @@ import pytest
 
 from sym.cli.saml_clients import SAMLClient
 from sym.cli.saml_clients.aws_okta import AwsOkta
+from sym.cli.saml_clients.aws_profile import AwsProfile
 from sym.cli.saml_clients.chooser import SAMLClientName, choose_saml_client
 from sym.cli.saml_clients.saml2aws import Saml2Aws
 from sym.cli.tests.helpers.sandbox import Sandbox
@@ -12,7 +13,7 @@ from sym.cli.tests.helpers.sandbox import Sandbox
 @pytest.mark.parametrize(
     argnames=("saml_client_name", "make_saml2aws", "expected"),
     argvalues=[
-        ("auto", False, AwsOkta),
+        ("auto", False, AwsProfile),
         ("auto", True, Saml2Aws),
         ("aws-okta", False, AwsOkta),
         ("aws-okta", True, AwsOkta),
